#!/usr/bin/perl

# Instructables Syndication System 2006-05-15
# use this script to automatically syndicate all of a user's projects in their user RSS feed
# script by: dgold at squid-labs.com

# run script from crontab every 60 minutes to refresh all project pages
# example crontab line:
# 0 * * * * /home/dgold/public_html/projects/instruct_getrss.pl

# this script requires the XML::RSS::Parser perl package, if you are using a hosting account
# which does not give you root access to install perl packages, here is how to install
# the package in your user account:
#
# mkdir ~/perl
# run 'cpan', and type 'install XML::RSS::Parser', then 'exit' 
# edit ~/.cpan/CPAN/MyConfig.pm as follows:
# change the 'makepl_arg' line to look like: 'makepl_arg' => q[PREFIX=~/perl INSTALLDIRS=site]
# save the file, then run 'cpan' and type 'install XML::RSS::Parser' and then 'force install XML::RSS::Parser'

# if your XML::RSS::Parser is installed in your user account, uncomment these lines
# and modify the paths to fit your install
#BEGIN {
#  unshift(@INC, "/home/dgold/perl/lib/perl/5.8.4", "/home/dgold/perl/share/perl/5.8.4");
#}

use XML::RSS::Parser;
use FileHandle;

# configuration parameters
$indexpage = "index.html";
$user = "dan";
$site = "http://www.instructables.com";

# get the rss page listing all projects
# change URL to any page with an RSS feed that you want to syndicate
`wget -O $user.rss.xml "$site/ex/u/$user/rss.xml?LIMIT=1000"`;
# for group rss feeds:
#`wget -O $user.rss.xml "$site/$user/rss.xml?LIMIT=1000"`;

$p = XML::RSS::Parser->new;
$rssfh = FileHandle->new("$user.rss.xml");
$feed = $p->parse_file($rssfh);

# read the rss feed to find all projects, get the full project pages
$count = $feed->item_count();
print("\ngot $count total items\n");

# read the rss feed and write an index page that links to all the complete projects
open(IDX, ">$indexpage.new") || die("couldn't write $indexpage.new");
foreach $item ($feed->query('//item')) {
  unless($item->query("category")) {
    next;
  }
  # all the data in the feed
  $title = $item->query("title")->text_content;
  $author = $item->query("author")->text_content;
  $description = $item->query("description")->text_content;
  $pubDate = $item->query("pubDate")->text_content;
  $link = $item->query("link")->text_content;
  $guid = $item->query("guid")->text_content;
  $tag = $item->query("category")->text_content;

  $link = "$site/partner?name=$user&style=all&format=html&project=$guid";

  # write out overview of a project with link to the full project page
  print(IDX "<b><a href=\"$link\">$title</a></b><br/>\n");
  # print(IDX "By: $author<br/>\n");
  print(IDX "Posted on: $pubDate<br/>\n");
  print(IDX $description . "<br clear=all><hr>\n");
}
close(IDX);

if(-e $indexpage) {
  unlink($indexpage) || die("couldn't delete old $indexpage");
}
rename("$indexpage.new", $indexpage) || die("couldn't update $indexpage");

